@@ -24,6 +24,7 @@
 import os
 import logging
 import inspect
+from operator import attrgetter
 
 logger = logging.getLogger('shovel')
 handler = logging.StreamHandler()
@@ -155,6 +156,8 @@ class Task(object):
                 remaining.extend(next.values())
             else:
                 found.append(next)
+        found.sort(key=attrgetter('fullname'))
+
         return found
     
     @classmethod
@@ -320,16 +323,16 @@ def help_helper(tasks):
 def help(*names):
     '''Display information about the provided task name, or available tasks'''
     if not len(names):
-        print help_helper(Task.find())
+        print(help_helper(Task.find()))
     else:
         for name in names:
             tasks = Task.find(name)
             if not tasks:
-                print 'Could not find task or module "%s"' % name
+                print('Could not find task or module "%s"' % name)
             elif len(tasks) == 1:
-                print tasks[0].help()
+                print(tasks[0].help())
             else:
-                print help_helper(tasks)
+                print(help_helper(tasks))
 
 def load():
     '''Load tasks from files'''
@@ -340,10 +343,10 @@ def load():
     import time
     p = os.path.abspath('./shovel.py')
     if os.path.isfile(p) and _files.get(p, 0) < os.stat(p).st_mtime:
-        with file(p) as f:
+        with open(p) as f:
             logger.info('Loading %s' % p)
             r = imp.find_module('shovel', ['.'])
-            module = imp.load_module('shovel', r[0], r[1], r[2])
+            module = imp.load_module('shovel', *r)
             _files[p] = os.stat(p).st_mtime
     elif os.path.isdir(os.path.abspath('./shovel')):
         for root, dirs, files in os.walk(os.path.abspath('./shovel')):
@@ -353,5 +356,5 @@ def load():
                     logger.info('Loading %s' % p)
                     name, sep, ext = name.rpartition('.py')
                     r = imp.find_module(name, [root])
-                    module = imp.load_module(name, r[0], r[1], r[2])
+                    module = imp.load_module(name, *r)
                     _files[p] = os.stat(p).st_mtime
